@@ -18,11 +18,11 @@
 export class GlobalWarningBannerDirective {
 
   restrict: string = 'E';
-  transclude: boolean = true;
   templateUrl: string = 'components/widget/global-warning-banner/global-warning-banner.html';
 
   scope = {
-    'messages': '='
+    'messages': '=',
+    'onClose': '&',
   };
 
 }
